#!/bin/sh
#
# Copyright (c) Members of the EGEE Collaboration. 2004-2010.
# See http://www.eu-egee.org/partners/ for details on the
# copyright holders. 
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
# These tests are rather lame - the Apel is run with a number of different
# configurations. The output of each test is then collected and compared
# to a set of specific messages found in the Apel program.
#
# Although not ideal, at the very least this offers a good chance to
# to check the various Apel processors are functioning as expected. 
#

if [ -z $APEL_HOME ]; then
  echo "APEL_HOME is not set"
  exit 1
fi

search() {
    grep "$1" $LOG >> /dev/null
    if [ $? != 0 ]; then
	echo test failed searching for \"$1\"
	FAIL=1
    fi
}

LOG=test-output.log

if [ -f $LOG ]; then
    rm $LOG
fi

FAIL=0
touch $LOG

PROG_BIN="$APEL_HOME/bin/apel-pbs-log-parser.sh"
CONFIG="`pwd`/config"

echo
echo "Running Apel - deleting all db records"
echo
echo "$PROG_BIN -f $CONFIG/del-config.xml"
time $PROG_BIN -f $CONFIG/del-config.xml >> $LOG 2>&1

echo
echo 'Running Apel - processing some PBS test files'
echo
echo "$PROG_BIN -f $CONFIG/ce-config.xml"
time $PROG_BIN -f $CONFIG/ce-config.xml >> $LOG 2>&1

echo
echo "Running Apel - processing some GK & Job Manager test files"
echo
echo "$PROG_BIN -f $CONFIG/gk-config.xml"
time $PROG_BIN -f $CONFIG/gk-config.xml >> $LOG 2>&1

echo
cat $LOG
