/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.pbs;

import java.io.File;
import java.io.IOException;

import org.glite.apel.core.log.type.EventRecord;

import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Tests to validate the functionality of the EvemtLogParser class.
 */
public class EventLogParserTest extends TestCase {
	
    private String day = "03";
    private String month = "01";
    private String year = "2004";
    private String hour = "07";
    private String minute = "04";
    private String second = "47";
    private String mDate = year + "-" + month + "-" + day;
    private String mTime = hour + ":" + minute + ":" + second;
    private int cpuHours = 26;
    private int cpuMinutes = 51;
    private int cpuSeconds = 27;
    private String jobID = "886293";
    private String submitHost = "pbs-server2";
    private String jobName = jobID + "." + submitHost;
    private String user = "quadt";
    private String group = "d0";
    private String memReal = "260268";
    private String memVirtual = "419172";
    private String startTime = "1077934810";
    private String stopTime = "1078121087";
    private int wallHours = 45;
    private int wallMins = 42;
    private int wallSecs = 2;
    private int wallTime = (wallHours * 60 * 60) + (wallMins * 60) +
        wallSecs;
    private String wallDuration = "P" + wallHours + "H" + wallMins +
        "M" + wallSecs + "S";
    private String cpuTime = "P" + cpuHours + "H" + cpuMinutes + "M" +
        cpuSeconds + "S";
    private int cpuTimeSeconds = (cpuHours * 60 * 60) +
        (cpuMinutes * 60) + cpuSeconds;

    public static junit.framework.Test suite() {
        return new TestSuite(EventLogParserTest.class);
    }

    /**
     * Constructs a dummy event record, returning it as a string.
     */
    private String constructEvent() {
        String dateTimePrefix = month + "/" + day + "/" + year +
            " " + hour + ":" + minute + ":" + second;
        String jobInfo = jobName + ";user=" + user + " group=" +
            group + " jobname=wjjjj_1_p14.05. " +
            "queue=e-long ctime=1077913598 qtime=1077913598 " +
            "etime=1077913598 start=" + startTime + " " +
            "exec_host=c01-001-108/1 Resource_List.cput=48:00:00 " +
            "Resource_List.ncpus=1 Resource_List.nodect=1 " +
            "Resource_List.pcput=48:00:00 Resource_List.walltime=96:00:00 " +
            "session=8083 end=" + stopTime +
            " Exit_status=0 resources_used.cpupercent=107 " +
            "resources_used.cput=" + cpuHours + ":" + cpuMinutes + ":" +
            cpuSeconds + " " + "resources_used.mem=" + memReal +
            "kb resources_used.ncpus=1 " + "resources_used.vmem=" + memVirtual +
            "kb resources_used.walltime=" + wallHours + ":" + wallMins + ":" +
            wallSecs;
        return dateTimePrefix + ";E;" + jobInfo;
    }

    /**
     * Checks the event parser successfully interprets an event log entry.
     */
    public void testParse() {
        String input = constructEvent();
        File tmp = null;
        try {
        	tmp = File.createTempFile("unittest", "tmp");
            tmp.deleteOnExit();
        } catch (IOException ioe) {
        	fail();
        }
        EventLogParser parser = new EventLogParser(tmp, "", "");
        EventRecord record = parser.createEventRecord(input);
        assertEquals(record.getCpuDuration(), cpuTime);
        assertEquals(record.getCpuDurationSeconds(),
            Integer.toString(cpuTimeSeconds));
        assertEquals(record.getJobName(), jobName);
        assertEquals(record.getLocalUserGroup(), group);
        assertEquals(record.getLocalUserID(), user);
        assertEquals(record.getEventDate(), mDate);
        assertEquals(record.getEventTime(), mTime);
        assertEquals(record.getMemoryReal(), memReal);
        assertEquals(record.getMemoryVirtual(), memVirtual);
        assertEquals(record.getStartTimeEpoch(), startTime);
        assertEquals(record.getStopTimeEpoch(), stopTime);
        assertEquals(record.getWallDurationSeconds(), Integer.toString(wallTime));
        assertEquals(record.getWallDuration(), wallDuration);
        assertEquals(record.getSubmitHost(), submitHost);
    }

}
